==> sortingview-0.2.17.tar.gz: sortingview-0.2.17/sortingview/gui/extensions/unitstable/Units/metricPlugins/peak_channels.py <==
import os
import hither2 as hi
import kachery_client as kc
import numpy as np
from sortingview.config import job_cache, job_handler

from labbox_ephys import prepare_snippets_h5
from labbox_ephys.helpers.get_unit_waveforms import get_unit_waveforms

@hi.function(
    'get_peak_channels', '0.1.0',
    image=hi.RemoteDockerImage('docker://magland/labbox-ephys-processing:0.3.19'),
    modules=['labbox_ephys']
)
def get_peak_channels(snippets_h5):
    import h5py
    h5_path = kc.load_file(snippets_h5)
    assert h5_path is not None
    ret = {}
    with h5py.File(h5_path, 'r') as f:
        unit_ids = np.array(f.get('unit_ids'))
        for unit_id in unit_ids:
            unit_waveforms = np.array(f.get(f'unit_waveforms/{unit_id}/waveforms')) # n x M x T
            channel_ids = np.array(f.get(f'unit_waveforms/{unit_id}/channel_ids')) # n
            peak_channel_index = _compute_peak_channel_index_from_waveforms(unit_waveforms)
            ret[str(unit_id)] = int(channel_ids[peak_channel_index])
    return ret

def _compute_peak_channel_index_from_waveforms(waveforms):
    average_waveform = np.mean(waveforms, axis=0)
    channel_amplitudes = (np.max(average_waveform, axis=1) - np.min(average_waveform, axis=1)).squeeze() # M
    peak_channel_index = np.argmax(channel_amplitudes)
    return peak_channel_index

@kc.taskfunction('get_peak_channels.1', type='pure-calculation')
def task_get_peak_channels(sorting_object, recording_object, configuration={}):
    with hi.Config(
        job_cache=job_cache,
        job_handler=job_handler.metrics
    ):
        snippets_h5 = prepare_snippets_h5.run(recording_object=recording_object, sorting_object=sorting_object)
        return get_peak_channels.run(
            snippets_h5=snippets_h5
        )

==> sortingview-0.2.18.tar.gz: sortingview-0.2.18/sortingview/gui/extensions/unitstable/Units/metricPlugins/peak_channels.py <==
import os
import hither2 as hi
import kachery_client as kc
import numpy as np
from sortingview.config import job_cache, job_handler

from labbox_ephys import prepare_snippets_h5
from labbox_ephys.helpers.get_unit_waveforms import get_unit_waveforms

@hi.function(
    'get_peak_channels', '0.1.0',
    image=hi.RemoteDockerImage('docker://magland/labbox-ephys-processing:0.3.19'),
    modules=['labbox_ephys']
)
def get_peak_channels(snippets_h5):
    import h5py
    h5_path = kc.load_file(snippets_h5)
    assert h5_path is not None
    ret = {}
    with h5py.File(h5_path, 'r') as f:
        unit_ids = np.array(f.get('unit_ids'))
        for unit_id in unit_ids:
            unit_waveforms = np.array(f.get(f'unit_waveforms/{unit_id}/waveforms')) # n x M x T
            channel_ids = np.array(f.get(f'unit_waveforms/{unit_id}/channel_ids')) # n
            peak_channel_index = _compute_peak_channel_index_from_waveforms(unit_waveforms)
            ret[str(unit_id)] = int(channel_ids[peak_channel_index])
    return ret

def _compute_peak_channel_index_from_waveforms(waveforms):
    average_waveform = np.mean(waveforms, axis=0)
    channel_amplitudes = (np.max(average_waveform, axis=1) - np.min(average_waveform, axis=1)).squeeze() # M
    peak_channel_index = np.argmax(channel_amplitudes)
    return peak_channel_index

@kc.taskfunction('get_peak_channels.1', type='pure-calculation')
def task_get_peak_channels(sorting_object, recording_object, configuration={}, snippets_len=(50, 80)):
    with hi.Config(
        job_cache=job_cache,
        job_handler=job_handler.metrics
    ):
        snippets_h5 = prepare_snippets_h5.run(recording_object=recording_object, sorting_object=sorting_object, snippets_len=snippets_len)
        return get_peak_channels.run(
            snippets_h5=snippets_h5
        )
